@@ -362,8 +362,7 @@ def Fishconsole_Update():
                             # 尝试获取缓存中的值
 
                             # 这是没有检查到值或者发现时执行的操作
-                            print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，请重新运行本程序，我们将尝试自动安装最新版本", "红色"))
-                            print(logs.日志(f"Fishconsole 模块已被禁用，解决方式为更新该模块", "红色"))
+                            print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，缓存刷新，我们将在下一次启动程序时自动更新", "红色"))
                             config = files.缓存(2)
                             系统日志(f"config is {config}", "强制更新系统help", UPI)
                             config["updata"] = True
