@@ -16,7 +16,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '2.2.0'
+    return '2.2.1'
 
 
 def f_debug():
@@ -390,9 +390,17 @@ def f_debug():
         elif b[0] in ["updata", "UPDATA"]:
             print(logs.日志("Fcv_debug Console》我们将尝试激活更新，在程序执行完毕以后，我们将阻止强制更新系统在下一次继续运行", "蓝色"))
             files.缓存(3, 数据={'updata': True})
+            files.缓存(3, 数据={'FHUM': True})
             Fishsys.Fishconsole_Update()
             files.缓存(3, 数据={'updata': False})
 
+            def temp():
+                from Fishconsole import helps
+                helps.帮助()
+            import time
+            time.sleep(3)
+            threading.Thread(target=temp).start()
+
         elif b[0] in ["execute"]:
             未选触发器 = True
             空容器 = ""
