@@ -9,7 +9,7 @@
 
 import os
 import sys
-from Fishconsole import fcv
+from Fishconsole import fcv,Fishsys#激活强制更新要用
 # 显示行列要用
 import signal
 
@@ -20,6 +20,8 @@ import chardet
 
 
 
+
+
 def 颜色(text, 色选="None"):
     """
     FishConsole LOGS颜色模块
